package com.ff.game.mapper;

import java.util.List;
import com.ff.game.domain.GameExchangeMoney;

/**
 * 会员金额转移记录Mapper接口
 * 
 * @author shi
 * @date 2025-02-10
 */
public interface GameExchangeMoneyMapper 
{
    /**
     * 查询会员金额转移记录
     * 
     * @param id 会员金额转移记录主键
     * @return 会员金额转移记录
     */
     GameExchangeMoney selectGameExchangeMoneyById(Long id);

    /**
     * 查询会员金额转移记录列表
     * 
     * @param gameExchangeMoney 会员金额转移记录
     * @return 会员金额转移记录集合
     */
     List<GameExchangeMoney> selectGameExchangeMoneyList(GameExchangeMoney gameExchangeMoney);

    /**
     * 新增会员金额转移记录
     * 
     * @param gameExchangeMoney 会员金额转移记录
     * @return 结果
     */
     int insertGameExchangeMoney(GameExchangeMoney gameExchangeMoney);

    /**
     * 修改会员金额转移记录
     * 
     * @param gameExchangeMoney 会员金额转移记录
     * @return 结果
     */
     int updateGameExchangeMoney(GameExchangeMoney gameExchangeMoney);

    /**
     * 删除会员金额转移记录
     * 
     * @param id 会员金额转移记录主键
     * @return 结果
     */
     int deleteGameExchangeMoneyById(Long id);

    /**
     * 批量删除会员金额转移记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteGameExchangeMoneyByIds(Long[] ids);
}
